"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveSnapshotPath = exports.verifyOutputPath = exports.resolveAbsolutePath = void 0;
const os_1 = require("os");
const path_1 = require("path");
const fs_1 = require("./fs");
const constants_1 = require("../constants");
const resolveAbsolutePath = (path) => {
    if ((0, path_1.isAbsolute)(path)) {
        return path;
    }
    if (path.startsWith('~')) {
        return path.replace('~', (0, os_1.homedir)());
    }
    return (0, path_1.join)(process.cwd(), path);
};
exports.resolveAbsolutePath = resolveAbsolutePath;
const verifyOutputPath = (_outputPath) => {
    const absLiskCorePath = (0, exports.resolveAbsolutePath)(constants_1.DEFAULT_LISK_CORE_PATH);
    const absOutputPath = (0, exports.resolveAbsolutePath)(_outputPath);
    if (absOutputPath.startsWith(absLiskCorePath)) {
        throw new Error(`Output path '${_outputPath}' is not allowed. Please restart the migrator with a different output path.`);
    }
};
exports.verifyOutputPath = verifyOutputPath;
const resolveSnapshotPath = async (useSnapshot, snapshotPath, dataDir, liskCoreV3DataPath) => {
    if (!useSnapshot)
        return (0, path_1.join)(liskCoreV3DataPath, constants_1.SNAPSHOT_DIR);
    if (snapshotPath && !snapshotPath.endsWith('.tar.gz'))
        return snapshotPath;
    const [snapshotDirNameExtracted] = (await (0, fs_1.getFiles)(dataDir));
    const snapshotFilePathExtracted = (0, path_1.join)(dataDir, snapshotDirNameExtracted);
    return snapshotFilePathExtracted;
};
exports.resolveSnapshotPath = resolveSnapshotPath;
//# sourceMappingURL=path.js.map